# litvarpy
[![Python package](https://github.com/seanD111/litvarpy/actions/workflows/python-package-pypi.yml/badge.svg)](https://github.com/seanD111/litvarpy/actions/workflows/python-package-pypi.yml)	[![codecov](https://codecov.io/gh/seanD111/litvarpy/branch/main/graph/badge.svg?token=UHWS9EWSAG)](https://codecov.io/gh/seanD111/litvarpy)


litvarpy is a python interface to the [LitVar public API](https://www.ncbi.nlm.nih.gov/CBBresearch/Lu/Demo/LitVar/api.html) 
for the querying and retrieval of variant-relevant information and associated biomedical literature.

 